==> angular.js_1.2.26.orig.tar.gz: angular.js-1.2.26/src/ngLocale/angular-locale_dyo-sn.js <==
'use strict';
angular.module("ngLocale", [], ["$provide", function($provide) {
var PLURAL_CATEGORY = {ZERO: "zero", ONE: "one", TWO: "two", FEW: "few", MANY: "many", OTHER: "other"};
function getDecimals(n) {
  n = n + '';
  var i = n.indexOf('.');
  return (i == -1) ? 0 : n.length - i - 1;
}

function getVF(n, opt_precision) {
  var v = opt_precision;

  if (undefined === v) {
    v = Math.min(getDecimals(n), 3);
  }

  var base = Math.pow(10, v);
  var f = ((n * base) | 0) % base;
  return {v: v, f: f};
}

$provide.value("$locale", {
  "DATETIME_FORMATS": {
    "AMPMS": [
      "AM",
      "PM"
    ],
    "DAY": [
      "Dimas",
      "Tene\u014b",
      "Talata",
      "Alarbay",
      "Aramisay",
      "Arjuma",
      "Sibiti"
    ],
    "MONTH": [
      "Sanvie",
      "F\u00e9birie",
      "Mars",
      "Aburil",
      "Mee",
      "Sue\u014b",
      "S\u00fauyee",
      "Ut",
      "Settembar",
      "Oktobar",
      "Novembar",
      "Disambar"
    ],
    "SHORTDAY": [
      "Dim",
      "Ten",
      "Tal",
      "Ala",
      "Ara",
      "Arj",
      "Sib"
    ],
    "SHORTMONTH": [
      "Sa",
      "Fe",
      "Ma",
      "Ab",
      "Me",
      "Su",
      "S\u00fa",
      "Ut",
      "Se",
      "Ok",
      "No",
      "De"
    ],
    "fullDate": "EEEE d MMMM y",
    "longDate": "d MMMM y",
    "medium": "d MMM y HH:mm:ss",
    "mediumDate": "d MMM y",
    "mediumTime": "HH:mm:ss",
    "short": "d/M/y HH:mm",
    "shortDate": "d/M/y",
    "shortTime": "HH:mm"
  },
  "NUMBER_FORMATS": {
    "CURRENCY_SYM": "CFA",
    "DECIMAL_SEP": ",",
    "GROUP_SEP": "\u00a0",
    "PATTERNS": [
      {
        "gSize": 3,
        "lgSize": 3,
        "maxFrac": 3,
        "minFrac": 0,
        "minInt": 1,
        "negPre": "-",
        "negSuf": "",
        "posPre": "",
        "posSuf": ""
      },
      {
        "gSize": 3,
        "lgSize": 3,
        "maxFrac": 2,
        "minFrac": 2,
        "minInt": 1,
        "negPre": "-",
        "negSuf": "\u00a0\u00a4",
        "posPre": "",
        "posSuf": "\u00a0\u00a4"
      }
    ]
  },
  "id": "dyo-sn",
  "pluralCat": function (n, opt_precision) {  var i = n | 0;  var vf = getVF(n, opt_precision);  if (i == 1 && vf.v == 0) {    return PLURAL_CATEGORY.ONE;  }  return PLURAL_CATEGORY.OTHER;}
});
}]);

==> angular.js_1.8.2.orig.tar.gz: angular.js-1.8.2/src/ngLocale/angular-locale_dyo-sn.js <==
'use strict';
angular.module("ngLocale", [], ["$provide", function($provide) {
var PLURAL_CATEGORY = {ZERO: "zero", ONE: "one", TWO: "two", FEW: "few", MANY: "many", OTHER: "other"};
function getDecimals(n) {
  n = n + '';
  var i = n.indexOf('.');
  return (i == -1) ? 0 : n.length - i - 1;
}

function getVF(n, opt_precision) {
  var v = opt_precision;

  if (undefined === v) {
    v = Math.min(getDecimals(n), 3);
  }

  var base = Math.pow(10, v);
  var f = ((n * base) | 0) % base;
  return {v: v, f: f};
}

$provide.value("$locale", {
  "DATETIME_FORMATS": {
    "AMPMS": [
      "AM",
      "PM"
    ],
    "DAY": [
      "Dimas",
      "Tene\u014b",
      "Talata",
      "Alarbay",
      "Aramisay",
      "Arjuma",
      "Sibiti"
    ],
    "ERANAMES": [
      "Ari\u014buu Yeesu",
      "Atoo\u014be Yeesu"
    ],
    "ERAS": [
      "ArY",
      "AtY"
    ],
    "FIRSTDAYOFWEEK": 0,
    "MONTH": [
      "Sanvie",
      "F\u00e9birie",
      "Mars",
      "Aburil",
      "Mee",
      "Sue\u014b",
      "S\u00fauyee",
      "Ut",
      "Settembar",
      "Oktobar",
      "Novembar",
      "Disambar"
    ],
    "SHORTDAY": [
      "Dim",
      "Ten",
      "Tal",
      "Ala",
      "Ara",
      "Arj",
      "Sib"
    ],
    "SHORTMONTH": [
      "Sa",
      "Fe",
      "Ma",
      "Ab",
      "Me",
      "Su",
      "S\u00fa",
      "Ut",
      "Se",
      "Ok",
      "No",
      "De"
    ],
    "STANDALONEMONTH": [
      "Sanvie",
      "F\u00e9birie",
      "Mars",
      "Aburil",
      "Mee",
      "Sue\u014b",
      "S\u00fauyee",
      "Ut",
      "Settembar",
      "Oktobar",
      "Novembar",
      "Disambar"
    ],
    "WEEKENDRANGE": [
      5,
      6
    ],
    "fullDate": "EEEE d MMMM y",
    "longDate": "d MMMM y",
    "medium": "d MMM y HH:mm:ss",
    "mediumDate": "d MMM y",
    "mediumTime": "HH:mm:ss",
    "short": "d/M/y HH:mm",
    "shortDate": "d/M/y",
    "shortTime": "HH:mm"
  },
  "NUMBER_FORMATS": {
    "CURRENCY_SYM": "CFA",
    "DECIMAL_SEP": ",",
    "GROUP_SEP": "\u00a0",
    "PATTERNS": [
      {
        "gSize": 3,
        "lgSize": 3,
        "maxFrac": 3,
        "minFrac": 0,
        "minInt": 1,
        "negPre": "-",
        "negSuf": "",
        "posPre": "",
        "posSuf": ""
      },
      {
        "gSize": 3,
        "lgSize": 3,
        "maxFrac": 0,
        "minFrac": 0,
        "minInt": 1,
        "negPre": "-",
        "negSuf": "\u00a0\u00a4",
        "posPre": "",
        "posSuf": "\u00a0\u00a4"
      }
    ]
  },
  "id": "dyo-sn",
  "localeID": "dyo_SN",
  "pluralCat": function(n, opt_precision) {  var i = n | 0;  var vf = getVF(n, opt_precision);  if (i == 1 && vf.v == 0) {    return PLURAL_CATEGORY.ONE;  }  return PLURAL_CATEGORY.OTHER;}
});
}]);
